@@ -87,6 +87,8 @@ sAppendN(&sbOut, "rxode2_fn2 dELUa;\n", 18);
 sAppendN(&sbOut, "rxode2_fn2 d2ELUa;\n", 19);
 sAppendN(&sbOut, "rxode2_fn3 logit;\n", 18);
 sAppendN(&sbOut, "rxode2_fn3 expit;\n", 18);
+sAppendN(&sbOut, "rxode2_fn3 probitInv;\n", 22);
+sAppendN(&sbOut, "rxode2_fn3 probit;\n", 19);
 sAppendN(&sbOut, "rxode2_fn2 gammap;\n", 19);
 sAppendN(&sbOut, "rxode2_fn2 gammaq;\n", 19);
 sAppendN(&sbOut, "rxode2_fn2 lowergamma;\n", 23);
@@ -215,6 +217,64 @@ sAppendN(&sbOut, "  }\n", 4);
 sAppendN(&sbOut, "  va_end(valist);\n", 18);
 sAppendN(&sbOut, "  return s;\n", 12);
 sAppendN(&sbOut, "}\n", 2);
+sAppendN(&sbOut, "double _mix(int _cSub, unsigned int n,  ...) {\n", 47);
+sAppendN(&sbOut, "  rx_solving_options_ind* ind = &(_solveData->subjects[_cSub]);\n", 64);
+sAppendN(&sbOut, "  va_list valist;\n", 18);
+sAppendN(&sbOut, "  double ret = NA_REAL;\n", 24);
+sAppendN(&sbOut, "  double p = 0.0;\n", 18);
+sAppendN(&sbOut, "  // In the case of simulating, mixunif is sampled once per patient\n", 68);
+sAppendN(&sbOut, "  double u = ind->mixunif;\n", 27);
+sAppendN(&sbOut, "  if (u >= 1.0) {\n", 18);
+sAppendN(&sbOut, "    // In this case, the mixest is assigned\n", 44);
+sAppendN(&sbOut, "    ind->mixest = u;\n", 21);
+sAppendN(&sbOut, "    u = 0;\n", 11);
+sAppendN(&sbOut, "    int found = 0;\n", 19);
+sAppendN(&sbOut, "    double v = 0.0;\n", 20);
+sAppendN(&sbOut, "    va_start(valist, n);\n", 25);
+sAppendN(&sbOut, "    for (unsigned int i = 0; i < n-1; i+= 2) {\n", 47);
+sAppendN(&sbOut, "      v = va_arg(valist, double);\n", 34);
+sAppendN(&sbOut, "      p += va_arg(valist, double);\n", 35);
+sAppendN(&sbOut, "      if (found == 0) {\n", 24);
+sAppendN(&sbOut, "        if (trunc(i*0.5 + 1) == trunc(ind->mixest)) {\n", 54);
+sAppendN(&sbOut, "          // This is the mixture selected\n", 42);
+sAppendN(&sbOut, "          ret = v;\n", 19);
+sAppendN(&sbOut, "          found = 1;\n", 21);
+sAppendN(&sbOut, "          ind->mixunif = u + (p - u)*0.5;\n", 42);
+sAppendN(&sbOut, "        }\n", 10);
+sAppendN(&sbOut, "        u = p;\n", 15);
+sAppendN(&sbOut, "      }\n", 8);
+sAppendN(&sbOut, "    }\n", 6);
+sAppendN(&sbOut, "    v = va_arg(valist, double); // other possibility\n", 53);
+sAppendN(&sbOut, "    if (found == 0) {\n", 22);
+sAppendN(&sbOut, "      ind->mixunif = u + (1.0 - u)*0.5;\n", 40);
+sAppendN(&sbOut, "      ret = v;\n", 15);
+sAppendN(&sbOut, "    }\n", 6);
+sAppendN(&sbOut, "    va_end(valist);\n", 20);
+sAppendN(&sbOut, "    return ret;\n", 16);
+sAppendN(&sbOut, "  } else {\n", 11);
+sAppendN(&sbOut, "    int found = 0;\n", 19);
+sAppendN(&sbOut, "    double v = 0.0;\n", 20);
+sAppendN(&sbOut, "    va_start(valist, n);\n", 25);
+sAppendN(&sbOut, "    for (unsigned int i = 0; i < n-1; i+= 2) {\n", 47);
+sAppendN(&sbOut, "      v = va_arg(valist, double);\n", 34);
+sAppendN(&sbOut, "      p += va_arg(valist, double);\n", 35);
+sAppendN(&sbOut, "      if (found == 0) {\n", 24);
+sAppendN(&sbOut, "        if (u < p) {\n", 21);
+sAppendN(&sbOut, "          ret = v;\n", 19);
+sAppendN(&sbOut, "          ind->mixest = i*0.5 + 1; // 1-based index\n", 52);
+sAppendN(&sbOut, "          found = 1;\n", 21);
+sAppendN(&sbOut, "        }\n", 10);
+sAppendN(&sbOut, "      }\n", 8);
+sAppendN(&sbOut, "    }\n", 6);
+sAppendN(&sbOut, "    v = va_arg(valist, double); // other possibility\n", 53);
+sAppendN(&sbOut, "    if (found == 0) {\n", 22);
+sAppendN(&sbOut, "      ind->mixest = _solveData->mixnum;\n", 40);
+sAppendN(&sbOut, "      ret = v;\n", 15);
+sAppendN(&sbOut, "    }\n", 6);
+sAppendN(&sbOut, "    va_end(valist);\n", 20);
+sAppendN(&sbOut, "    return ret;\n", 16);
+sAppendN(&sbOut, "  }\n", 4);
+sAppendN(&sbOut, "}\n", 2);
 sAppendN(&sbOut, "double _rxord(int _cSub, unsigned int n,  ...) {\n", 49);
 sAppendN(&sbOut, "  rx_solving_options_ind* ind = &(_solveData->subjects[_cSub]);\n", 64);
 sAppendN(&sbOut, "  if (!ind->inLhs) {\n", 21);
