@@ -6,13 +6,7 @@
 #include "../inst/include/rxode2.h"
 #include "../inst/include/rxode2parse.h"
 #include <R.h>
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 using namespace Rcpp;
 using namespace arma;
 
