@@ -217,4 +217,73 @@ rxTest({
       expect_error(assertParameterValue(NA))
     })
   }
+
+  test_that("no warnings/errors without boundaries", {
+
+    one.cmt <- function() {
+      ini({
+        tka <- 0.45; label("Ka")
+        tcl <- log(2.7); label("Cl")
+        tv <- 3.45; label("V")
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        iov.cl ~ 0.1 | occ
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+      model({
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl + iov.cl)
+        v <- exp(tv + eta.v)
+        linCmt() ~ add(add.sd)
+      })
+    }
+
+    expect_error(suppressWarnings(assertRxUiIovNoCor(one.cmt)), NA)
+
+    one.cmt <- function() {
+      ini({
+        tka <- 0.45; label("Ka")
+        tcl <- log(2.7); label("Cl")
+        tv <- 3.45; label("V")
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        iov.cl ~ 0.1 | occ
+        iov.v ~ 0.1 | occ
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+      model({
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl + iov.cl)
+        v <- exp(tv + eta.v + iov.v)
+        linCmt() ~ add(add.sd)
+      })
+    }
+
+    expect_error(suppressWarnings(assertRxUiIovNoCor(one.cmt)), NA)
+
+    one.cmt <- function() {
+      ini({
+        tka <- 0.45; label("Ka")
+        tcl <- log(2.7); label("Cl")
+        tv <- 3.45; label("V")
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        iov.cl + iov.v ~ c(0.1,
+                           0.001, 0.1) | occ
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+      model({
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl + iov.cl)
+        v <- exp(tv + eta.v + iov.v)
+        linCmt() ~ add(add.sd)
+      })
+    }
+    expect_error(suppressWarnings(assertRxUiIovNoCor(one.cmt)))
+
+  })
+
 })
