@@ -1,6 +1,6 @@
 if (!.Call(`_rxode2_isIntel`)) {
   test_that("Cleanly unloads all dlls", {
     skip_on_os("windows")
-    expect_null(rxUnloadAll())
+    expect_true(rxUnloadAll())
   })
 }
